The LostAndFound Dataset addresses the problem of detecting unexpected small
obstacles on the road often caused by lost cargo. The dataset comprises 112
stereo video sequences with 2104 annotated frames (picking roughly every tenth
frame from the recorded data).

The dataset is designed analogous to the 'Cityscapes' dataset. The datset
provides: - stereo image pairs in either 8 or 16 bit color resolution -
precomputed disparity maps - coarse semantic labels for objects and street

Descriptions of the labels are given here:
http://www.6d-vision.com/laf_table.pdf
